@@ -1,69 +1,5 @@
 var NAVTREEINDEX72 =
 {
-"rfnoc__tx__radio__pydoc__template_8h.html#ac5c1a8bf4435de092cf9322c6678d8dd":[7,0,34,2,0,0,0,11,12],
-"rfnoc__tx__radio__pydoc__template_8h.html#ac7e9ebc4491444b4b607366044169fb2":[7,0,34,2,0,0,0,11,8],
-"rfnoc__tx__radio__pydoc__template_8h.html#acbd1840181f2ccce3416891da7159fab":[7,0,34,2,0,0,0,11,5],
-"rfnoc__tx__radio__pydoc__template_8h.html#ae068c4c38579159aac6fbff836cab706":[7,0,34,2,0,0,0,11,13],
-"rfnoc__tx__radio__pydoc__template_8h.html#ae6bc2e8e6b52522a8f5bd077b5e712a2":[7,0,34,2,0,0,0,11,9],
-"rfnoc__tx__radio__pydoc__template_8h.html#af17c3b4b4f030cab9bd18503f077a9f2":[7,0,34,2,0,0,0,11,17],
-"rfnoc__tx__radio__pydoc__template_8h_source.html":[7,0,34,2,0,0,0,11],
-"rfnoc__tx__streamer_8h.html":[7,0,34,1,0,0,14],
-"rfnoc__tx__streamer_8h_source.html":[7,0,34,1,0,0,14],
-"rfnoc__tx__streamer__pydoc__template_8h.html":[7,0,34,2,0,0,0,12],
-"rfnoc__tx__streamer__pydoc__template_8h.html#a09556fea44983454f09905a535251b62":[7,0,34,2,0,0,0,12,4],
-"rfnoc__tx__streamer__pydoc__template_8h.html#a426c9a6c22ebecb7693dfb06cbf15f67":[7,0,34,2,0,0,0,12,1],
-"rfnoc__tx__streamer__pydoc__template_8h.html#a70d3cba11c85d3432da2818769384a73":[7,0,34,2,0,0,0,12,2],
-"rfnoc__tx__streamer__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,34,2,0,0,0,12,0],
-"rfnoc__tx__streamer__pydoc__template_8h.html#adc871898a22f084c10ed3b1fdd45c526":[7,0,34,2,0,0,0,12,3],
-"rfnoc__tx__streamer__pydoc__template_8h.html#aff22f2d2430b6b07f03f0318531cefcb":[7,0,34,2,0,0,0,12,5],
-"rfnoc__tx__streamer__pydoc__template_8h_source.html":[7,0,34,2,0,0,0,12],
-"rfnoc__window_8h.html":[7,0,34,1,0,0,15],
-"rfnoc__window_8h_source.html":[7,0,34,1,0,0,15],
-"rfnoc__window__pydoc__template_8h.html":[7,0,34,2,0,0,0,13],
-"rfnoc__window__pydoc__template_8h.html#a0c3911571f587b22b5a3487b47337833":[7,0,34,2,0,0,0,13,1],
-"rfnoc__window__pydoc__template_8h.html#a28a58f17f6037716bd2b4379d8f35435":[7,0,34,2,0,0,0,13,3],
-"rfnoc__window__pydoc__template_8h.html#a4ff148f2a56bee5f774beaccde027817":[7,0,34,2,0,0,0,13,5],
-"rfnoc__window__pydoc__template_8h.html#a551d5138da5f8069844784e6a4cfe2b4":[7,0,34,2,0,0,0,13,2],
-"rfnoc__window__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,34,2,0,0,0,13,0],
-"rfnoc__window__pydoc__template_8h.html#a8ed39aad21dcb0c51dfadfcee2cb9cbe":[7,0,34,2,0,0,0,13,4],
-"rfnoc__window__pydoc__template_8h_source.html":[7,0,34,2,0,0,0,13],
-"rms__cf_8h.html":[7,0,9,1,0,0,108],
-"rms__cf_8h_source.html":[7,0,9,1,0,0,108],
-"rms__cf__pydoc__template_8h.html":[7,0,9,2,0,0,0,105],
-"rms__cf__pydoc__template_8h.html#a0e18bd9dfbf934f4316d7b67411fff64":[7,0,9,2,0,0,0,105,1],
-"rms__cf__pydoc__template_8h.html#a30f05c23e1f5c5770b9ffc5281dbf2c3":[7,0,9,2,0,0,0,105,5],
-"rms__cf__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,105,0],
-"rms__cf__pydoc__template_8h.html#a7439b7c2d9617c98cb222a83d9280402":[7,0,9,2,0,0,0,105,3],
-"rms__cf__pydoc__template_8h.html#ace7fa71e0b84ca19624b4c009dd5a4d7":[7,0,9,2,0,0,0,105,2],
-"rms__cf__pydoc__template_8h.html#aedf49b0d0d0a957db2f9109e6efb72aa":[7,0,9,2,0,0,0,105,4],
-"rms__cf__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,105],
-"rms__ff_8h.html":[7,0,9,1,0,0,109],
-"rms__ff_8h_source.html":[7,0,9,1,0,0,109],
-"rms__ff__pydoc__template_8h.html":[7,0,9,2,0,0,0,106],
-"rms__ff__pydoc__template_8h.html#a04a3b76e18dabefaa89e7882b4650dfe":[7,0,9,2,0,0,0,106,1],
-"rms__ff__pydoc__template_8h.html#a288e8f944fde7f479c6ab1e4b6a06f11":[7,0,9,2,0,0,0,106,5],
-"rms__ff__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,106,0],
-"rms__ff__pydoc__template_8h.html#a8f4c817c2b258613f05a8e71ed883795":[7,0,9,2,0,0,0,106,4],
-"rms__ff__pydoc__template_8h.html#acf36f37967dda96d279d8c8724c11abf":[7,0,9,2,0,0,0,106,2],
-"rms__ff__pydoc__template_8h.html#ae7ba9215a5b30b19540c2e959f6c9f5d":[7,0,9,2,0,0,0,106,3],
-"rms__ff__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,106],
-"rotator_8h.html":[7,0,9,1,0,0,110],
-"rotator_8h_source.html":[7,0,9,1,0,0,110],
-"rotator__cc_8h.html":[7,0,9,1,0,0,111],
-"rotator__cc_8h_source.html":[7,0,9,1,0,0,111],
-"rotator__cc__pydoc__template_8h.html":[7,0,9,2,0,0,0,107],
-"rotator__cc__pydoc__template_8h.html#a33b145cc5b206241c1960439dbc72006":[7,0,9,2,0,0,0,107,3],
-"rotator__cc__pydoc__template_8h.html#a55313c3a732591a72ba50f24180a6f4a":[7,0,9,2,0,0,0,107,4],
-"rotator__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,107,0],
-"rotator__cc__pydoc__template_8h.html#a7757abfd75bbf899338fe7339a7e726d":[7,0,9,2,0,0,0,107,1],
-"rotator__cc__pydoc__template_8h.html#aad48194c4aff9f631bc7e77aef8c6bdd":[7,0,9,2,0,0,0,107,5],
-"rotator__cc__pydoc__template_8h.html#afee5362309cea4c600aa626aa0b0ee61":[7,0,9,2,0,0,0,107,2],
-"rotator__cc__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,107],
-"rotator__pydoc__template_8h.html":[7,0,9,2,0,0,0,108],
-"rotator__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,108,0],
-"rotator__pydoc__template_8h.html#a80191b545e82cb6529dd4d5c9715a6d3":[7,0,9,2,0,0,0,108,3],
-"rotator__pydoc__template_8h.html#a8031229ec8909741c53291f4160d8e2e":[7,0,9,2,0,0,0,108,6],
-"rotator__pydoc__template_8h.html#a937bc8990e3cc2e0557c91aef39cc6bf":[7,0,9,2,0,0,0,108,1],
 "rotator__pydoc__template_8h.html#a94ca7787156825af12d59fac07c88732":[7,0,9,2,0,0,0,108,2],
 "rotator__pydoc__template_8h.html#a9856ac6d027acf766c0cf709f638db7c":[7,0,9,2,0,0,0,108,7],
 "rotator__pydoc__template_8h.html#ab7162277732d3fa23b7d83bda979984d":[7,0,9,2,0,0,0,108,5],
@@ -249,5 +185,69 @@ var NAVTREEINDEX72 =
 "short__to__float_8h_source.html":[7,0,9,1,0,0,115],
 "short__to__float__pydoc__template_8h.html":[7,0,9,2,0,0,0,112],
 "short__to__float__pydoc__template_8h.html#a058f6c6e5bf1a6623ff2d3ec35e12dcb":[7,0,9,2,0,0,0,112,4],
-"short__to__float__pydoc__template_8h.html#a62add767a292b37e183222008f5db22f":[7,0,9,2,0,0,0,112,3]
+"short__to__float__pydoc__template_8h.html#a62add767a292b37e183222008f5db22f":[7,0,9,2,0,0,0,112,3],
+"short__to__float__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,9,2,0,0,0,112,0],
+"short__to__float__pydoc__template_8h.html#a8ae3d23d6b0d7da578642439fe399acf":[7,0,9,2,0,0,0,112,2],
+"short__to__float__pydoc__template_8h.html#aabf05ede1a4c7c8c4d17ccb87992494c":[7,0,9,2,0,0,0,112,6],
+"short__to__float__pydoc__template_8h.html#ae34ec22af2e3534fbc95ea694c0c5891":[7,0,9,2,0,0,0,112,1],
+"short__to__float__pydoc__template_8h.html#aeacabb06e0ea7b9c028d00e9c7dd8ead":[7,0,9,2,0,0,0,112,5],
+"short__to__float__pydoc__template_8h_source.html":[7,0,9,2,0,0,0,112],
+"sig__source_8h.html":[7,0,5,1,0,0,30],
+"sig__source_8h_source.html":[7,0,5,1,0,0,30],
+"sig__source__pydoc__template_8h.html":[7,0,5,2,0,0,0,29],
+"sig__source__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,5,2,0,0,0,29,0],
+"sig__source__pydoc__template_8h_source.html":[7,0,5,2,0,0,0,29],
+"sig__source__waveform_8h.html":[7,0,5,1,0,0,31],
+"sig__source__waveform_8h_source.html":[7,0,5,1,0,0,31],
+"sig__source__waveform__pydoc__template_8h.html":[7,0,5,2,0,0,0,30],
+"sig__source__waveform__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,5,2,0,0,0,30,0],
+"sig__source__waveform__pydoc__template_8h_source.html":[7,0,5,2,0,0,0,30],
+"simple__framer__sync__pydoc__template_8h.html":[7,0,13,2,0,0,0,81],
+"simple__framer__sync__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,13,2,0,0,0,81,0],
+"simple__framer__sync__pydoc__template_8h_source.html":[7,0,13,2,0,0,0,81],
+"simple__squelch__cc_8h.html":[7,0,5,1,0,0,32],
+"simple__squelch__cc_8h_source.html":[7,0,5,1,0,0,32],
+"simple__squelch__cc__pydoc__template_8h.html":[7,0,5,2,0,0,0,31],
+"simple__squelch__cc__pydoc__template_8h.html#a1d35907997db57cbd29a0f89c9e9cfa3":[7,0,5,2,0,0,0,31,4],
+"simple__squelch__cc__pydoc__template_8h.html#a457b447bfe82b887c40f533e381ef5ac":[7,0,5,2,0,0,0,31,2],
+"simple__squelch__cc__pydoc__template_8h.html#a497750dd4ead63715b17c0491ed832f6":[7,0,5,2,0,0,0,31,6],
+"simple__squelch__cc__pydoc__template_8h.html#a66c6597f494482b2c7ea35be9da51247":[7,0,5,2,0,0,0,31,8],
+"simple__squelch__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,5,2,0,0,0,31,0],
+"simple__squelch__cc__pydoc__template_8h.html#a95e3bb6b1b56203605715bdbaaac7f1c":[7,0,5,2,0,0,0,31,9],
+"simple__squelch__cc__pydoc__template_8h.html#a9a0abe09f484723e565018aa8316cce0":[7,0,5,2,0,0,0,31,3],
+"simple__squelch__cc__pydoc__template_8h.html#aafd65ef19a30d912012b9d2a24f46ba7":[7,0,5,2,0,0,0,31,1],
+"simple__squelch__cc__pydoc__template_8h.html#af0473891d03c400d80f4524bd8b4a581":[7,0,5,2,0,0,0,31,5],
+"simple__squelch__cc__pydoc__template_8h.html#af7553e08b7ef5a9e1f7ff6ef53469d97":[7,0,5,2,0,0,0,31,7],
+"simple__squelch__cc__pydoc__template_8h_source.html":[7,0,5,2,0,0,0,31],
+"sincos_8h.html":[7,0,3,0,0,55],
+"sincos_8h_source.html":[7,0,3,0,0,55],
+"sincos__pydoc__template_8h.html":[7,0,3,1,0,0,0,0,35],
+"sincos__pydoc__template_8h.html#a4be35dc6eec575c85fa8e49cc90a204b":[7,0,3,1,0,0,0,0,35,1],
+"sincos__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,3,1,0,0,0,0,35,0],
+"sincos__pydoc__template_8h.html#a8ea312a7c68f1c0935f5044dfca484cf":[7,0,3,1,0,0,0,0,35,2],
+"sincos__pydoc__template_8h_source.html":[7,0,3,1,0,0,0,0,35],
+"single__pole__iir_8h.html":[7,0,21,1,0,0,43],
+"single__pole__iir_8h_source.html":[7,0,21,1,0,0,43],
+"single__pole__iir__filter__cc_8h.html":[7,0,21,1,0,0,44],
+"single__pole__iir__filter__cc_8h_source.html":[7,0,21,1,0,0,44],
+"single__pole__iir__filter__cc__pydoc__template_8h.html":[7,0,21,2,0,0,0,40],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#a2fc5946776e68b03600f3f2b1921aa14":[7,0,21,2,0,0,0,40,2],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#a47103bd2e1d7812b5d3375bb955434b6":[7,0,21,2,0,0,0,40,3],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,40,0],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#addab234a28d515726ed52563ee887618":[7,0,21,2,0,0,0,40,1],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#ae414e1975ae5a1ef88efb73e14ecb5b8":[7,0,21,2,0,0,0,40,4],
+"single__pole__iir__filter__cc__pydoc__template_8h.html#af0e81b1180f2b79fe3199b5aa43a54e9":[7,0,21,2,0,0,0,40,5],
+"single__pole__iir__filter__cc__pydoc__template_8h_source.html":[7,0,21,2,0,0,0,40],
+"single__pole__iir__filter__ff_8h.html":[7,0,21,1,0,0,45],
+"single__pole__iir__filter__ff_8h_source.html":[7,0,21,1,0,0,45],
+"single__pole__iir__filter__ff__pydoc__template_8h.html":[7,0,21,2,0,0,0,41],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#a209614cb73194a0f9ed14eb36433eaac":[7,0,21,2,0,0,0,41,4],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#a46ebbeb90417173ff90ed041077cd81c":[7,0,21,2,0,0,0,41,1],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,41,0],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#a917dee6ccd50b0028d3b9e245ed2e7d5":[7,0,21,2,0,0,0,41,2],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#aed88fb4abb90dfdc0ea12fd983a35c96":[7,0,21,2,0,0,0,41,5],
+"single__pole__iir__filter__ff__pydoc__template_8h.html#afeb3df48b901467d5937248e88496cbc":[7,0,21,2,0,0,0,41,3],
+"single__pole__iir__filter__ff__pydoc__template_8h_source.html":[7,0,21,2,0,0,0,41],
+"single__pole__iir__pydoc__template_8h.html":[7,0,21,2,0,0,0,42],
+"single__pole__iir__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,21,2,0,0,0,42,0]
 };
